==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.rdiff/src/com/openexchange/rdiff/internal/ChecksumPairImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rdiff.internal;

import org.metastatic.rsync.ChecksumPair;


/**
 * {@link ChecksumPairImpl} - The checksum pair implementation.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ChecksumPairImpl implements com.openexchange.rdiff.ChecksumPair {

    private final ChecksumPair checksumPair;

    /**
     * Initializes a new {@link ChecksumPairImpl}.
     */
    public ChecksumPairImpl(final ChecksumPair checksumPair) {
        super();
        this.checksumPair = checksumPair;
    }

    @Override
    public int getWeak() {
        return checksumPair.getWeak();
    }

    @Override
    public byte[] getStrong() {
        return checksumPair.getStrong();
    }

    @Override
    public long getOffset() {
        return checksumPair.getOffset();
    }

    @Override
    public int getLength() {
        return checksumPair.getLength();
    }

    @Override
    public int getSequence() {
        return checksumPair.getSequence();
    }

    @Override
    public int hashCode() {
        return checksumPair.hashCode();
    }

    @Override
    public boolean equals(final Object obj) {
        return checksumPair.equals(obj);
    }

    @Override
    public String toString() {
        return checksumPair.toString();
    }
}

==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.rdiff/src/com/openexchange/rdiff/internal/ChecksumPairImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rdiff.internal;

import org.metastatic.rsync.ChecksumPair;


/**
 * {@link ChecksumPairImpl} - The checksum pair implementation.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ChecksumPairImpl implements com.openexchange.rdiff.ChecksumPair {

    private final ChecksumPair checksumPair;

    /**
     * Initializes a new {@link ChecksumPairImpl}.
     */
    public ChecksumPairImpl(final ChecksumPair checksumPair) {
        super();
        this.checksumPair = checksumPair;
    }

    @Override
    public int getWeak() {
        return checksumPair.getWeak();
    }

    @Override
    public byte[] getStrong() {
        return checksumPair.getStrong();
    }

    @Override
    public long getOffset() {
        return checksumPair.getOffset();
    }

    @Override
    public int getLength() {
        return checksumPair.getLength();
    }

    @Override
    public int getSequence() {
        return checksumPair.getSequence();
    }

    @Override
    public int hashCode() {
        return checksumPair.hashCode();
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof ChecksumPairImpl)) {
            return false;
        }
        final ChecksumPairImpl other = (ChecksumPairImpl) obj;
        if (null == checksumPair) {
            if (null != other.checksumPair) {
                return false;
            }
        } else if (!checksumPair.equals(other.checksumPair)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return checksumPair.toString();
    }
}
